intelmq.bots.collectors.alienvault_otx package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.alienvault_otx package

## Submodules

## intelmq.bots.collectors.alienvault_otx.collector module

class intelmq.bots.collectors.alienvault_otx.collector.AlienVaultOTXCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect reports from the AlienVault OTX Collector API. Report varies according to subscriptions.

  api_key: str = '<insert your api key>'
  init()
  interval: int = 24
  modified_pulses_only: bool = False
  process()
  rate_limit: int = 3600

intelmq.bots.collectors.alienvault_otx.collector.BOT

  alias of `intelmq.bots.collectors.alienvault_otx.collector.AlienVaultOTXCollectorBot`

## Module contents